@@ -16,6 +16,22 @@ class IAMRolesStack(Stack):
         codebuild_svc_role_dictionary = permission.readIAMRolePolicyStatements(iam_roles_dir, "codebuild_svc_role")
         self.codebuild_svc_role = permission.createIAMServiceRole(self, codebuild_svc_role_dictionary)
 
+        ##
+        ## CodePipeline Service Role
+        codepipeline_svc_role_dictionary = permission.readIAMRolePolicyStatements(iam_roles_dir, "codepipeline_svc_role")
+        self.codepipeline_svc_role = permission.createIAMServiceRole(self, codepipeline_svc_role_dictionary)
+
+        ## 
+        ## Lambda Service Role
+
+
+        ## 
+        ## EKS Service Role
+        
+
+        ##
+        ## VPC Service Role
+
 
 
 
